/***********************************************************************
*
* Copyright (c) 2021-2022 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
 public:
   MainWindow();

 private:
   void infoMsg();
   void questionMsg();
   void warnMsg();

   QLineEdit *info_text;
   QLineEdit *quest_text;
   QLineEdit *warn_text;
};

MainWindow::MainWindow()
{
   setMinimumSize(700, 350);

   QPushButton *info_pb = new QPushButton("Information");
   info_text = new QLineEdit();

   QPushButton *quest_pb = new QPushButton("Question");
   quest_text = new QLineEdit();

   QPushButton *warn_pb = new QPushButton("Warning");
   warn_text = new QLineEdit();

   //
   QPushButton *close_pb = new QPushButton();
   close_pb->setText("Close");

   QGridLayout *grid1 = new QGridLayout();
   grid1->setContentsMargins(75, 45, 75, 25);
   grid1->setHorizontalSpacing(20);
   grid1->setVerticalSpacing(45);

   grid1->addWidget(info_pb, 0, 0);
   grid1->addWidget(info_text, 0, 1);

   grid1->addWidget(quest_pb, 1, 0);
   grid1->addWidget(quest_text, 1, 1);

   grid1->addWidget(warn_pb, 2, 0);
   grid1->addWidget(warn_text, 2, 1);

   QHBoxLayout *layout1 = new QHBoxLayout();
   layout1->addStretch();
   layout1->addWidget(close_pb);
   layout1->addStretch();

   QVBoxLayout *layoutMain = new QVBoxLayout(this);
   layoutMain->addLayout(grid1);
   layoutMain->addSpacing(75);
   layoutMain->addLayout(layout1);

   connect(info_pb,     &QPushButton::clicked, this, &MainWindow::infoMsg);
   connect(quest_pb,    &QPushButton::clicked, this, &MainWindow::questionMsg);
   connect(warn_pb,     &QPushButton::clicked, this, &MainWindow::warnMsg);

   connect(close_pb,   &QPushButton::clicked,  this, &QWidget::close);
}

void MainWindow::infoMsg()
{
   QMessageBox::StandardButton reply;

   reply = QMessageBox::information(this, "Information",
      "Body of informative message. Click OK, X icon, or press Esc");

   // since no buttons were passed, reply can only be OK
   info_text->setText("OK");
}

void MainWindow::questionMsg()
{
   QMessageBox::StandardButton reply;

   reply = QMessageBox::question(this, "Question",
       "Body of a question. Click one of the buttons, X icon, or press Esc",
        QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel);

   if (reply == QMessageBox::Yes) {
      quest_text->setText("Yes");

   } else if (reply == QMessageBox::No)  {
      quest_text->setText("No");

   } else {
      quest_text->setText("Cancel");
   }
}

void MainWindow::warnMsg()
{
   QMessageBox msgBox(QMessageBox::Warning, "Warning",
     "Body of a warning message. Click one of the buttons, X icon, or press Esc",
      Qt::EmptyFlag, this);

   msgBox.addButton("Save",   QMessageBox::AcceptRole);
   msgBox.addButton("Ignore", QMessageBox::RejectRole);

   if (msgBox.exec() == QMessageBox::AcceptRole) {
      warn_text->setText("Save");

   } else {
      warn_text->setText("Ignore");
   }
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}

